%global debug_package %{nil}

Name: docker-cli
Version: %{_version}
Release: 13%{?dist}

Summary: The open-source application container engine
Group: Tools/Docker
License: ASL 2.0
Source0: cli.tgz
Source1: plugin-installers.tgz
Source11: docker-storage-config.sh
URL: https://dockerproject.org
Vendor: Docker
Packager: Oracle America

# required packages on install
Requires: /bin/sh

BuildRequires: make
BuildRequires: libtool-ltdl-devel
BuildRequires: golang >= 1.15

# conflicting packages
Conflicts: docker < 18.09
Conflicts: docker-io
Conflicts: docker-engine-cs
Conflicts: docker-ee
Conflicts: docker-ee-cli

# Obsolete packages
Obsoletes: docker < 1.6.1-2.0.1.el7

%description
Docker is an open source project to build, ship and run any application as a
lightweight container.

Docker containers are both hardware-agnostic and platform-agnostic. This means
they can run anywhere, from your laptop to the largest EC2 compute instance and
everything in between - and they don't require you to use a particular
language, framework or packaging system. That makes them great building blocks
for deploying and scaling web apps, databases, and backend services without
depending on a particular stack or provider.

%prep
%setup -q -c -n src -a 1

%build
mkdir -p /go/src/github.com/docker
rm -f /go/src/github.com/docker/cli
ln -s /root/rpmbuild/BUILD/src/cli /go/src/github.com/docker/cli
pushd /go/src/github.com/docker/cli
DISABLE_WARN_OUTSIDE_CONTAINER=1 make VERSION=%{_origversion} GITCOMMIT=%{_gitcommit} dynbinary manpages # cli
popd

# Build all associated plugins
pushd /root/rpmbuild/BUILD/src/plugins
for installer in *.installer; do
    bash ${installer} build
done
popd


# %check
# cli/build/docker -v

%install
# install binary
install -d $RPM_BUILD_ROOT/%{_bindir}
install -p -m 755 cli/build/docker $RPM_BUILD_ROOT/%{_bindir}/docker

# install plugins
pushd /root/rpmbuild/BUILD/src/plugins
for installer in *.installer; do
    DESTDIR=$RPM_BUILD_ROOT \
        PREFIX=/usr/libexec/docker/cli-plugins \
        bash ${installer} install_plugin
done
popd

# add bash, zsh, and fish completions
install -d $RPM_BUILD_ROOT/usr/share/bash-completion/completions
install -d $RPM_BUILD_ROOT/usr/share/zsh/site-functions
install -d $RPM_BUILD_ROOT/usr/share/fish/vendor_completions.d
install -p -m 644 cli/contrib/completion/bash/docker $RPM_BUILD_ROOT/usr/share/bash-completion/completions/docker
install -p -m 644 cli/contrib/completion/zsh/_docker $RPM_BUILD_ROOT/usr/share/zsh/site-functions/_docker
install -p -m 644 cli/contrib/completion/fish/docker.fish $RPM_BUILD_ROOT/usr/share/fish/vendor_completions.d/docker.fish

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 cli/man/man1/*.1 $RPM_BUILD_ROOT/%{_mandir}/man1
install -d %{buildroot}%{_mandir}/man5
install -p -m 644 cli/man/man5/*.5 $RPM_BUILD_ROOT/%{_mandir}/man5
install -d %{buildroot}%{_mandir}/man8
install -p -m 644 cli/man/man8/*.8 $RPM_BUILD_ROOT/%{_mandir}/man8

mkdir -p build-docs
for cli_file in LICENSE MAINTAINERS NOTICE README.md; do
    cp "cli/$cli_file" "build-docs/$cli_file"
done

# ORACLE
# install contrib storage script
install -p -m 755 %SOURCE11 $RPM_BUILD_ROOT/%{_bindir}/docker-storage-config


# list files owned by the package here
%files
%doc build-docs/LICENSE build-docs/MAINTAINERS build-docs/NOTICE build-docs/README.md
/%{_bindir}/docker
/%{_bindir}/docker-storage-config
/usr/libexec/docker/cli-plugins/*
/usr/share/bash-completion/completions/docker
/usr/share/zsh/site-functions/_docker
/usr/share/fish/vendor_completions.d/docker.fish
%doc
/%{_mandir}/man1/*
/%{_mandir}/man5/*
/%{_mandir}/man8/*
%license build-docs/LICENSE

%post
if ! getent group docker > /dev/null; then
    groupadd --system docker
fi

%changelog
* Thu Jul 22 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-13
- updated containerd minimum version to 1.4.8 to address CVE-2021-32760.

* Fri Jul 09 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-12
- Addressed oraBug 33099096 docker: Error response from daemon: unable to find user 0: invalid argument. 

* Thu Jun 24 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-11
- Addresses CVE-2021-30465 - updated minimum version of runc in docker-engine >= 3:1.0.0-1.rc95.

* Tue Jun 22 2021 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 19.03.11-10
- Addresses runc CVE-2021-30465 - updated runc versions in cli/vendor.conf and docker-engine/vendor.conf to 1.0.0-rc95.

* Mon Apr 12 2021 <luis.daniel.carvallo@oracle.com> 19.03.11-9
- Bugfix for "docker pull" from private repo fails after successful login

* Wed Feb 10 2021 <michael.a.thompson@oracle.com> 19.03.11-8
- Patch for missing license file

* Thu Dec 3 2020 <michael.a.thompson@oracle.com> 19.03.11-7
- Fix for CVE-2020-15257

* Fri Oct 16 2020 <michael.a.thompson@oracle.com> 19.03.11-6
- Fix for CVE-2020-15157

* Tue Aug 18 2020 <michael.a.thompson@oracle.com> 19.03.11-5
- Bugfix for "docker images [name]" not working on docker 19.03.11-ol
- Address CVE-2020-16845

* Thu Jun 18 2020 <michael.a.thompson@oracle.com> 19.03.11-4
- added patch for registry list

* Tue Jun 2 2020 <michael.a.thompson@oracle.com> 19.03.11-3
- update to 19.03.11 for CVE-2020-13401

* Tue Jul 30 2019 <michael.calunod@oracle.com> 19.03.1-1.0.0
- update to 19.03.1

* Thu Jul 25 2019 <michael.calunod@oracle.com> 19.03-0.0.1
- update to 19.03

* Tue May 14 2019 <michael.calunod@oracle.com> 18.09.1-1.0.6
- disable kmem accounting for UEKR4

* Mon Feb 11 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.5
- apply e4931e664feac6fa8846f3f04268a0cc98822549, fixes CVE-2019-5736

* Sun Feb 10 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.4
- fix authentication error when using docker hub and using --default-registry

* Sat Feb  9 2019 <laszlo.peter@oracle.com> 18.09.1-1.0.3
- fix authentication errors when using docker hub

* Wed Jan  9 2019 <laszlo.peter@oracle.com> 18.09-1.0.0
- rename to docker-cli

* Wed Sep 26 2018 <laszlo.peter@oracle.com> 18.09-0.0.1
- merge docker-engine.spec changes by Oracle into docker-ce-cli.spec from
  upstream 18.09 branch
